pub struct SessionSecurity {
session: WeakRef<Session>,
crypto_identity_state: Cell<CryptoIdentityState>,
verification_state: Cell<SessionVerificationState>,
recovery_state: Cell<RecoveryState>,
cross_signing_keys_available: Cell<bool>,
backup_enabled: Cell<bool>,
backup_exists_on_server: Cell<bool>,
abort_handles: RefCell<Vec<AbortHandle>>,
}Fields
session: WeakRef<Session>The current session.
crypto_identity_state: Cell<CryptoIdentityState>The state of the crypto identity for the current session.
verification_state: Cell<SessionVerificationState>The state of the verification for the current session.
recovery_state: Cell<RecoveryState>The state of recovery for the current session.
cross_signing_keys_available: Cell<bool>Whether all the cross-signing keys are available.
backup_enabled: Cell<bool>Whether the room keys backup is enabled.
backup_exists_on_server: Cell<bool>Whether the room keys backup exists on the homeserver.
abort_handles: RefCell<Vec<AbortHandle>>Implementations
Sourceimpl SessionSecurity
impl SessionSecurity
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl SessionSecurity
impl SessionSecurity
Sourcefn set_session(&self, session: Option<&Session>)
fn set_session(&self, session: Option<&Session>)
Set the current session.
Sourcepub(super) fn set_crypto_identity_state(&self, state: CryptoIdentityState)
pub(super) fn set_crypto_identity_state(&self, state: CryptoIdentityState)
Set the crypto identity state of the current session.
Sourcepub(super) fn set_verification_state(&self, state: SessionVerificationState)
pub(super) fn set_verification_state(&self, state: SessionVerificationState)
Set the verification state of the current session.
Sourcepub(super) fn set_recovery_state(&self, state: RecoveryState)
pub(super) fn set_recovery_state(&self, state: RecoveryState)
Set the recovery state of the current session.
Sourcepub(super) fn set_cross_signing_keys_available(&self, available: bool)
pub(super) fn set_cross_signing_keys_available(&self, available: bool)
Set whether all the cross-signing keys are available.
Sourcepub(super) fn set_backup_enabled(&self, enabled: bool)
pub(super) fn set_backup_enabled(&self, enabled: bool)
Set whether the room keys backup is enabled.
Sourcepub(super) fn set_backup_exists_on_server(&self, exists: bool)
pub(super) fn set_backup_exists_on_server(&self, exists: bool)
Set whether the room keys backup exists on the homeserver.
Sourceasync fn watch_crypto_identity_state(&self)
async fn watch_crypto_identity_state(&self)
Listen to crypto identity changes.
Sourceasync fn load_crypto_identity_state(&self)
async fn load_crypto_identity_state(&self)
Load the crypto identity state.
Sourcefn watch_verification_state(&self)
fn watch_verification_state(&self)
Listen to verification state changes.
Sourcefn watch_recovery_state(&self)
fn watch_recovery_state(&self)
Listen to recovery state changes.
Sourceasync fn update_recovery_state(&self, state: RecoveryState)
async fn update_recovery_state(&self, state: RecoveryState)
Update the session for the given recovery state.